import * as React from "react";
import * as ReactDom from "react-dom";
import { PropertyPaneFieldType } from "@microsoft/sp-property-pane";
import { update } from "@microsoft/sp-lodash-subset";
import Checklist from "./components/Checklist";
var PropertyPaneChecklistControl = /** @class */ (function () {
    function PropertyPaneChecklistControl(targetProperty, properties) {
        this.type = PropertyPaneFieldType.Custom;
        this.targetProperty = targetProperty;
        this.properties = {
            key: properties.label,
            disabled: properties.disabled,
            items: properties.items,
            checkedKeys: properties.checkedKeys,
            label: properties.label,
            onPropertyChange: properties.onPropertyChange,
            onRender: this.onRender.bind(this),
            onDispose: this.onDispose.bind(this),
            render: properties.render,
            properties: properties.properties
        };
    }
    PropertyPaneChecklistControl.prototype.render = function () {
        if (!this.elem) {
            return;
        }
        this.onRender(this.elem);
    };
    PropertyPaneChecklistControl.prototype.onDispose = function (element) {
        ReactDom.unmountComponentAtNode(element);
    };
    PropertyPaneChecklistControl.prototype.onRender = function (elem) {
        if (!this.elem) {
            this.elem = elem;
        }
        var element = React.createElement(Checklist, {
            label: this.properties.label,
            items: this.properties.items,
            checkedKeys: this.properties.checkedKeys,
            disabled: this.properties.disabled,
            onChanged: this.onChanged.bind(this),
            // required to allow the component to be re-rendered by calling this.render() externally
            stateKey: new Date().toString()
        });
        ReactDom.render(element, elem);
    };
    PropertyPaneChecklistControl.prototype.onChanged = function (checkedKeys) {
        update(this.properties.properties, this.targetProperty, function () {
            return checkedKeys;
        });
        this.properties.onPropertyChange(this.targetProperty, checkedKeys);
        this.properties.render();
    };
    return PropertyPaneChecklistControl;
}());
var PropertyPaneChecklist = function (targetProperty, properties) {
    return new PropertyPaneChecklistControl(targetProperty, properties);
};
export { PropertyPaneChecklist };
//# sourceMappingURL=PropertyPaneChecklist.js.map